```
Usage: vcd gateway services nat update-snat [OPTIONS] <gateway name> <nat rule
                                            id>

Options:
  -o, --original-ip <ip/ip range>
                                  original IP address/Range of SNAT Rule
  -t, --translated-ip <ip/ip range>
                                  translated IP address/Range of SNAT Rule
  --enabled / --disable           enable/disable the SNAT rule
  --logging-enabled / --logging-disable
                                  enable logging
  --desc <str>                    description of SNAT Rule
  --vnic <vnic>                   interface of gateway
  -h, --help                      Show this message and exit.

```
